import { string, object, arrayOf, oneOfType, node } from "prop-types";
import { STATUS } from "./StatusData";
import { Stack } from "@mui/material";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import ErrorOutlineIcon from "@mui/icons-material/ErrorOutline";

const propTypes = {
  status: string,
  theme: object,
  children: oneOfType([arrayOf(node), node])
};

const commonStyles = {
  position: "absolute",
  top: "-10px",
  left: "14px",
  fontSize: "20px"
};

export const StatusBadge = ({ status, theme, children }) => (
  <Stack sx={{ position: "relative" }}>
    {children}
    {status === STATUS.warning ||
    status === STATUS.inactiveWarning ||
    status === STATUS.disabledWarning ? (
      <WarningAmberIcon
        sx={{ fill: theme.palette.warning.main, ...commonStyles }}
      />
    ) : (
      <>
        {status === STATUS.alert ||
        status === STATUS.inactiveAlert ||
        status === STATUS.disabledAlert ? (
          <ErrorOutlineIcon
            sx={{ fill: theme.palette.error.main, ...commonStyles }}
          />
        ) : null}
      </>
    )}
  </Stack>
);

StatusBadge.propTypes = propTypes;
